@@ -1,5 +1,7 @@
 if [ -x /usr/bin/scrollkeeper-update ]; then
   /usr/bin/scrollkeeper-update -p /var/lib/scrollkeeper 1> /dev/null 2> /dev/null
 fi
+( cd var/lib/log ; rm -rf gdm )
+( cd var/lib/log ; ln -sf ../../log/gdm gdm )
 ( cd usr/bin ; rm -rf gdmXnest )
 ( cd usr/bin ; ln -sf gdmXnestchooser gdmXnest )
